# data minimization tools ![Python package](https://github.com/peng-data-minimization/minimizer/workflows/Python%20package/badge.svg)
Pyhton library for data minimization tools.
## Installation
### local installation
To install package locally run 

`pip install .`



### installation from PyPi
tdb.

To publish on PyPi see [here](https://python-packaging.readthedocs.io/en/latest/minimal.html#publishing-on-pypi).

## Documentation
[Read the Docs](https://data-minimization-tools.readthedocs.io/en/latest/)